@@ -9,31 +9,38 @@
 #include <errno.h>
 #include <locale.h>
 #include <math.h>
+#ifdef HAVE_NL_TYPES_H
 #include <nl_types.h>
+#else
+typedef long nl_catd;
+static nl_catd catopen(const char *name, int oflag) { return 0; }
+static const char *catgets(nl_catd catd, int set_id, int msg_id, const char *msg) { return msg; }
+static void catclose(nl_catd catd) { }
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include <getopt.h>
-#include <config.h>
+#include "getopt.h"
+#include "config.h"
 
 #include "misc.h"
 #include "sentence.h"
 /*}}}*/
 /* #defines */ /*{{{*/
-#define USAGE1  catgets(catd,1, 1,"Usage: style [-L language] [-l length] [-r ari] [file ...]\n")
-#define USAGE2  catgets(catd,1, 2,"       style [--language language] [--print-long length] [--print-ari ari]\n             [file ...]\n")
-#define USAGE3  catgets(catd,1, 3,"       style --version\n")
-#define MORE    catgets(catd,1, 4,"Try style -h|--help for more information.\n")
-#define HELP1   catgets(catd,1, 5,"Analyse surface characteristics of a document.\n")
-#define HELP2   catgets(catd,1, 6,"-L, --language    set the document language.\n")
-#define HELP3   catgets(catd,1, 7,"-l, --print-long  print all sentences longer than <length> words\n")
-#define HELP4   catgets(catd,1, 8,"-r, --print-ari   print all sentences with an ARI greater than than <ari>\n")
-#define HELP5   catgets(catd,1, 9,"-h, --help        print this message\n")
-#define HELP6   catgets(catd,1,10,"    --version     print the version\n")
-#define NOFILE  catgets(catd,1,11,"style: can not open %s: %s\n")
-#define NOSENT  catgets(catd,1,12,"No sentences found.\n")
-#define NOMEM   catgets(catd,1,13,"style: out of memory\n")
+#define USAGE1     catgets(catd,1, 1,"Usage: style [-L language] [-l length] [-r ari] [file ...]\n")
+#define USAGE2     catgets(catd,1, 2,"       style [--language language] [--print-long length] [--print-ari ari]\n             [file ...]\n")
+#define USAGE3     catgets(catd,1, 3,"       style --version\n")
+#define MORE       catgets(catd,1, 4,"Try style -h|--help for more information.\n")
+#define HELP1      catgets(catd,1, 5,"Analyse surface characteristics of a document.\n")
+#define HELP2      catgets(catd,1, 6,"-L, --language    set the document language.\n")
+#define HELP3      catgets(catd,1, 7,"-l, --print-long  print all sentences longer than <length> words\n")
+#define HELP4      catgets(catd,1, 8,"-r, --print-ari   print all sentences with an ARI greater than than <ari>\n")
+#define HELP5      catgets(catd,1, 9,"-h, --help        print this message\n")
+#define HELP6      catgets(catd,1,10,"    --version     print the version\n")
+#define OPENFAILED catgets(catd,1,11,"style: can not open %s: %s\n")
+#define NOSENT     catgets(catd,1,12,"No sentences found.\n")
+#define NOMEM      catgets(catd,1,13,"style: out of memory\n")
 /*}}}*/
 
 /* variables */ /*{{{*/
@@ -155,19 +162,19 @@ static double flesch(int syllables, int words, int sentences) /*{{{*/
  */
 static double fog(int words, int bigwords, int sentences) /*{{{*/
 {
-  return ((((double)words)/sentences+((double)bigwords)/words*100)*0.4);
+  return ((((double)words)/sentences+(100.0*bigwords)/words)*0.4);
 }
 /*}}}*/
 
 /**
- * Calculate 1. neue Wiener Sachtextformel (WSFT).
+ * Calculate 1. neue Wiener Sachtextformel (WSTF).
  * @param words the number of words in the text
  * @param shortwords the number of words that contain one syllable
  * @param longwords the number of words that are longer than 6 characters
  * @param bigwords the number of words that contain more than 3 syllables
  * @param sentences number of sentences
  */
-static double wsft(int words, int shortwords, int longwords, int bigwords, int sentences) /*{{{*/
+static double wstf(int words, int shortwords, int longwords, int bigwords, int sentences) /*{{{*/
 {
   return 0.1935*((double)bigwords)/words+0.1672*((double)words)/sentences-0.1297*((double)longwords)/words-0.0327*((double)shortwords)/words-0.875;
 }
@@ -184,7 +191,7 @@ static double wsft(int words, int shortwords, int longwords, int bigwords, int s
  */
 static double wheeler_smith(int *grade, int words, int bigwords, int sentences) /*{{{*/
 {
-  double index=((double)words)/sentences*((double)bigwords)/words/10.0;
+  double index=(((double)words)/sentences) * 10.0 * (((double)bigwords)/words);
   if (index<=16) *grade=0;
   else if (index<=20) *grade=5;
   else if (index<=24) *grade=6;
@@ -208,7 +215,7 @@ static double wheeler_smith(int *grade, int words, int bigwords, int sentences)
  */
 static double lix(int *grade, int words, int longwords, int sentences) /*{{{*/
 {
-  double index=((double)words)/sentences+((double)longwords)/words;
+  double index=((double)words)/sentences+100.0*((double)longwords)/words;
   if (index<34) *grade=0;
   else if (index<38) *grade=5;
   else if (index<41) *grade=6;
@@ -229,8 +236,8 @@ static double lix(int *grade, int words, int longwords, int sentences) /*{{{*/
  */
 static double smog(int bigwords, int sentences) /*{{{*/
 {
-  if (strncmp(docLanguage,"de",2)==0) return sqrt(((double)bigwords)*((double)sentences)/30)-2.0;
-  else return sqrt((double)bigwords*((double)sentences))+3.0;
+  if (strncmp(docLanguage,"de",2)==0) return sqrt(((double)bigwords)/((double)sentences)*30)-2.0;
+  else return sqrt((double)bigwords/((double)sentences)*30)+3.0;
 }
 /*}}}*/
 /*}}}*/
@@ -515,7 +522,7 @@ int main(int argc, char *argv[]) /*{{{*/
   else while (optind<argc)
   {
     FILE *fp;
-    if ((fp=fopen(argv[optind],"r"))==(FILE*)0) fprintf(stderr,NOFILE,argv[optind],strerror(errno));
+    if ((fp=fopen(argv[optind],"r"))==(FILE*)0) fprintf(stderr,OPENFAILED,argv[optind],strerror(errno));
     {
       sentence("style",catd,fp,argv[optind],style,docLanguage);
       fclose(fp);
@@ -538,7 +545,7 @@ int main(int argc, char *argv[]) /*{{{*/
     printf("        Coleman-Liau: %.1f\n",coleman_liau(characters,words,sentences));
     printf("        Flesch Index: %.1f\n",flesch(syllables,words,sentences));
     printf("        Fog Index: %.1f\n",fog(words,bigwords,sentences));
-    printf("        1. WSFT Index: %.1f\n",wsft(words,shortwords,longwords,bigwords,sentences));
+    printf("        1. WSTF Index: %.1f\n",wstf(words,shortwords,longwords,bigwords,sentences));
     printf("        Wheeler-Smith Index: %.1f = ",wheeler_smith(&wsg,words,bigwords,sentences));
     if (wsg==0) printf("below school year 5\n");
     else if (wsg==99) printf("higher than school year 10\n");
